@@ -6,7 +6,7 @@ import fire
 from .cloud.aws.monitor import Billing
 from .snippets import print_snippet, get_snippet
 from .boto3_wrapper import Boto3Wrapper
-from .git import GitProjects
+from .tls import SSLCert
 
 
 class TechboxCli:
@@ -16,8 +16,6 @@ class TechboxCli:
         snippet = get_snippet(path, from_line, to_line)
         print_snippet(snippet)
 
-    project = GitProjects()
-
     @staticmethod
     def aws_instances_info(fields=None):
         boto3_wrapper = Boto3Wrapper()
@@ -36,6 +34,16 @@ class TechboxCli:
         billing = Billing()
         print(billing.get_monthly_blended_cost())
 
+    @staticmethod
+    def get_ssl_expiration(hostname, port=443, timeout=10):
+        ssl = SSLCert(hostname=hostname, port=port, timeout=timeout)
+        print(ssl.get_cert_expiration_to_json())
+
+    @staticmethod
+    def get_ssl(hostname, port=443, timeout=10):
+        ssl = SSLCert(hostname=hostname, port=port, timeout=timeout)
+        print(ssl.to_json())
+
 
 def ep():
     fire.Fire(TechboxCli)
